@@ -1,39 +1,41 @@
 # Ultralytics 🚀 AGPL-3.0 License - https://ultralytics.com/license
 
 from pathlib import Path
+from typing import List, Optional, Union
 
 from ultralytics import SAM, YOLO
 
 
 def auto_annotate(
-    data,
-    det_model="yolo11x.pt",
-    sam_model="sam_b.pt",
-    device="",
-    conf=0.25,
-    iou=0.45,
-    imgsz=640,
-    max_det=300,
-    classes=None,
-    output_dir=None,
-):
+    data: Union[str, Path],
+    det_model: str = "yolo11x.pt",
+    sam_model: str = "sam_b.pt",
+    device: str = "",
+    conf: float = 0.25,
+    iou: float = 0.45,
+    imgsz: int = 640,
+    max_det: int = 300,
+    classes: Optional[List[int]] = None,
+    output_dir: Optional[Union[str, Path]] = None,
+) -> None:
     """
     Automatically annotate images using a YOLO object detection model and a SAM segmentation model.
 
     This function processes images in a specified directory, detects objects using a YOLO model, and then generates
-    segmentation masks using a SAM model. The resulting annotations are saved as text files.
+    segmentation masks using a SAM model. The resulting annotations are saved as text files in YOLO format.
 
     Args:
         data (str | Path): Path to a folder containing images to be annotated.
         det_model (str): Path or name of the pre-trained YOLO detection model.
         sam_model (str): Path or name of the pre-trained SAM segmentation model.
-        device (str): Device to run the models on (e.g., 'cpu', 'cuda', '0').
+        device (str): Device to run the models on (e.g., 'cpu', 'cuda', '0'). Empty string for auto-selection.
         conf (float): Confidence threshold for detection model.
         iou (float): IoU threshold for filtering overlapping boxes in detection results.
         imgsz (int): Input image resize dimension.
         max_det (int): Maximum number of detections per image.
-        classes (List[int] | None): Filter predictions to specified class IDs, returning only relevant detections.
-        output_dir (str | Path | None): Directory to save the annotated results. If None, a default directory is created.
+        classes (List[int], optional): Filter predictions to specified class IDs, returning only relevant detections.
+        output_dir (str | Path, optional): Directory to save the annotated results. If None, creates a default
+            directory based on the input data path.
 
     Examples:
         >>> from ultralytics.data.annotator import auto_annotate
@@ -52,7 +54,7 @@ def auto_annotate(
     )
 
     for result in det_results:
-        class_ids = result.boxes.cls.int().tolist()  # noqa
+        class_ids = result.boxes.cls.int().tolist()  # Extract class IDs from detection results
         if class_ids:
             boxes = result.boxes.xyxy  # Boxes object for bbox outputs
             sam_results = sam_model(result.orig_img, bboxes=boxes, verbose=False, save=False, device=device)
