@@ -2,6 +2,7 @@
 """Convolution modules."""
 
 import math
+from typing import List
 
 import numpy as np
 import torch
@@ -314,7 +315,7 @@ class Focus(nn.Module):
         """
         Apply Focus operation and convolution to input tensor.
 
-        Input shape is (b,c,w,h) and output shape is (b,4c,w/2,h/2).
+        Input shape is (B, C, W, H) and output shape is (B, 4C, W/2, H/2).
 
         Args:
             x (torch.Tensor): Input tensor.
@@ -479,8 +480,8 @@ class RepConv(nn.Module):
             branch (Conv | nn.BatchNorm2d | None): Branch to fuse.
 
         Returns:
-            (torch.Tensor): Fused kernel
-            (torch.Tensor): Fused bias
+            kernel (torch.Tensor): Fused kernel.
+            bias (torch.Tensor): Fused bias.
         """
         if branch is None:
             return 0, 0
@@ -668,7 +669,7 @@ class Concat(nn.Module):
         super().__init__()
         self.d = dimension
 
-    def forward(self, x):
+    def forward(self, x: List[torch.Tensor]):
         """
         Concatenate input tensors along specified dimension.
 
@@ -699,7 +700,7 @@ class Index(nn.Module):
         super().__init__()
         self.index = index
 
-    def forward(self, x):
+    def forward(self, x: List[torch.Tensor]):
         """
         Select and return a particular index from input.
 
