@@ -4,12 +4,15 @@ import io
 from typing import Any, List
 
 import cv2
+import torch
 
 from ultralytics import YOLO
 from ultralytics.utils import LOGGER
 from ultralytics.utils.checks import check_requirements
 from ultralytics.utils.downloads import GITHUB_ASSETS_STEMS
 
+torch.classes.__path__ = []  # Torch module __path__._path issue: https://github.com/datalab-to/marker/issues/442
+
 
 class Inference:
     """
@@ -49,7 +52,7 @@ class Inference:
         >>> inf.inference()
     """
 
-    def __init__(self, **kwargs: Any):
+    def __init__(self, **kwargs: Any) -> None:
         """
         Initialize the Inference class, checking Streamlit requirements and setting up the model path.
 
@@ -77,7 +80,7 @@ class Inference:
 
         LOGGER.info(f"Ultralytics Solutions: ✅ {self.temp_dict}")
 
-    def web_ui(self):
+    def web_ui(self) -> None:
         """Set up the Streamlit web interface with custom HTML elements."""
         menu_style_cfg = """<style>MainMenu {visibility: hidden;}</style>"""  # Hide main menu style
 
@@ -96,7 +99,7 @@ class Inference:
         self.st.markdown(main_title_cfg, unsafe_allow_html=True)
         self.st.markdown(sub_title_cfg, unsafe_allow_html=True)
 
-    def sidebar(self):
+    def sidebar(self) -> None:
         """Configure the Streamlit sidebar for model and inference settings."""
         with self.st.sidebar:  # Add Ultralytics LOGO
             logo = "https://raw.githubusercontent.com/ultralytics/assets/main/logo/Ultralytics_Logotype_Original.svg"
@@ -117,7 +120,7 @@ class Inference:
         self.org_frame = col1.empty()  # Container for original frame
         self.ann_frame = col2.empty()  # Container for annotated frame
 
-    def source_upload(self):
+    def source_upload(self) -> None:
         """Handle video file uploads through the Streamlit interface."""
         self.vid_file_name = ""
         if self.source == "video":
@@ -130,10 +133,18 @@ class Inference:
         elif self.source == "webcam":
             self.vid_file_name = 0  # Use webcam index 0
 
-    def configure(self):
+    def configure(self) -> None:
         """Configure the model and load selected classes for inference."""
         # Add dropdown menu for model selection
-        available_models = [x.replace("yolo", "YOLO") for x in GITHUB_ASSETS_STEMS if x.startswith("yolo11")]
+        M_ORD, T_ORD = ["yolo11n", "yolo11s", "yolo11m", "yolo11l", "yolo11x"], ["", "-seg", "-pose", "-obb", "-cls"]
+        available_models = sorted(
+            [
+                x.replace("yolo", "YOLO")
+                for x in GITHUB_ASSETS_STEMS
+                if any(x.startswith(b) for b in M_ORD) and "grayscale" not in x
+            ],
+            key=lambda x: (M_ORD.index(x[:7].lower()), T_ORD.index(x[7:].lower() or "")),
+        )
         if self.model_path:  # If user provided the custom model, insert model without suffix as *.pt is added later
             available_models.insert(0, self.model_path.split(".pt", 1)[0])
         selected_model = self.st.sidebar.selectbox("Model", available_models)
@@ -150,7 +161,7 @@ class Inference:
         if not isinstance(self.selected_ind, list):  # Ensure selected_options is a list
             self.selected_ind = list(self.selected_ind)
 
-    def inference(self):
+    def inference(self) -> None:
         """Perform real-time object detection inference on video or webcam feed."""
         self.web_ui()  # Initialize the web interface
         self.sidebar()  # Create the sidebar
