@@ -3,7 +3,7 @@
 from collections import abc
 from itertools import repeat
 from numbers import Number
-from typing import List
+from typing import List, Union
 
 import numpy as np
 
@@ -59,7 +59,7 @@ class Bboxes:
         This class does not handle normalization or denormalization of bounding boxes.
     """
 
-    def __init__(self, bboxes, format="xyxy") -> None:
+    def __init__(self, bboxes: np.ndarray, format: str = "xyxy") -> None:
         """
         Initialize the Bboxes class with bounding box data in a specified format.
 
@@ -74,7 +74,7 @@ class Bboxes:
         self.bboxes = bboxes
         self.format = format
 
-    def convert(self, format):
+    def convert(self, format: str) -> None:
         """
         Convert bounding box format from one type to another.
 
@@ -93,7 +93,7 @@ class Bboxes:
         self.bboxes = func(self.bboxes)
         self.format = format
 
-    def areas(self):
+    def areas(self) -> np.ndarray:
         """Calculate the area of bounding boxes."""
         return (
             (self.bboxes[:, 2] - self.bboxes[:, 0]) * (self.bboxes[:, 3] - self.bboxes[:, 1])  # format xyxy
@@ -101,7 +101,7 @@ class Bboxes:
             else self.bboxes[:, 3] * self.bboxes[:, 2]  # format xywh or ltwh
         )
 
-    def mul(self, scale):
+    def mul(self, scale: Union[int, tuple, list]) -> None:
         """
         Multiply bounding box coordinates by scale factor(s).
 
@@ -118,7 +118,7 @@ class Bboxes:
         self.bboxes[:, 2] *= scale[2]
         self.bboxes[:, 3] *= scale[3]
 
-    def add(self, offset):
+    def add(self, offset: Union[int, tuple, list]) -> None:
         """
         Add offset to bounding box coordinates.
 
@@ -135,12 +135,12 @@ class Bboxes:
         self.bboxes[:, 2] += offset[2]
         self.bboxes[:, 3] += offset[3]
 
-    def __len__(self):
+    def __len__(self) -> int:
         """Return the number of bounding boxes."""
         return len(self.bboxes)
 
     @classmethod
-    def concatenate(cls, boxes_list: List["Bboxes"], axis=0) -> "Bboxes":
+    def concatenate(cls, boxes_list: List["Bboxes"], axis: int = 0) -> "Bboxes":
         """
         Concatenate a list of Bboxes objects into a single Bboxes object.
 
@@ -163,7 +163,7 @@ class Bboxes:
             return boxes_list[0]
         return cls(np.concatenate([b.bboxes for b in boxes_list], axis=axis))
 
-    def __getitem__(self, index) -> "Bboxes":
+    def __getitem__(self, index: Union[int, np.ndarray, slice]) -> "Bboxes":
         """
         Retrieve a specific bounding box or a set of bounding boxes using indexing.
 
@@ -220,13 +220,20 @@ class Instances:
         ... )
     """
 
-    def __init__(self, bboxes, segments=None, keypoints=None, bbox_format="xywh", normalized=True) -> None:
+    def __init__(
+        self,
+        bboxes: np.ndarray,
+        segments: np.ndarray = None,
+        keypoints: np.ndarray = None,
+        bbox_format: str = "xywh",
+        normalized: bool = True,
+    ) -> None:
         """
         Initialize the Instances object with bounding boxes, segments, and keypoints.
 
         Args:
             bboxes (np.ndarray): Bounding boxes with shape (N, 4).
-            segments (List | np.ndarray, optional): Segmentation masks.
+            segments (np.ndarray, optional): Segmentation masks.
             keypoints (np.ndarray, optional): Keypoints with shape (N, 17, 3) in format (x, y, visible).
             bbox_format (str): Format of bboxes.
             normalized (bool): Whether the coordinates are normalized.
@@ -236,7 +243,7 @@ class Instances:
         self.normalized = normalized
         self.segments = segments
 
-    def convert_bbox(self, format):
+    def convert_bbox(self, format: str) -> None:
         """
         Convert bounding box format.
 
@@ -246,11 +253,11 @@ class Instances:
         self._bboxes.convert(format=format)
 
     @property
-    def bbox_areas(self):
+    def bbox_areas(self) -> np.ndarray:
         """Calculate the area of bounding boxes."""
         return self._bboxes.areas()
 
-    def scale(self, scale_w, scale_h, bbox_only=False):
+    def scale(self, scale_w: float, scale_h: float, bbox_only: bool = False):
         """
         Scale coordinates by given factors.
 
@@ -268,7 +275,7 @@ class Instances:
             self.keypoints[..., 0] *= scale_w
             self.keypoints[..., 1] *= scale_h
 
-    def denormalize(self, w, h):
+    def denormalize(self, w: int, h: int) -> None:
         """
         Convert normalized coordinates to absolute coordinates.
 
@@ -286,7 +293,7 @@ class Instances:
             self.keypoints[..., 1] *= h
         self.normalized = False
 
-    def normalize(self, w, h):
+    def normalize(self, w: int, h: int) -> None:
         """
         Convert absolute coordinates to normalized coordinates.
 
@@ -304,7 +311,7 @@ class Instances:
             self.keypoints[..., 1] /= h
         self.normalized = True
 
-    def add_padding(self, padw, padh):
+    def add_padding(self, padw: int, padh: int) -> None:
         """
         Add padding to coordinates.
 
@@ -320,7 +327,7 @@ class Instances:
             self.keypoints[..., 0] += padw
             self.keypoints[..., 1] += padh
 
-    def __getitem__(self, index) -> "Instances":
+    def __getitem__(self, index: Union[int, np.ndarray, slice]) -> "Instances":
         """
         Retrieve a specific instance or a set of instances using indexing.
 
@@ -346,7 +353,7 @@ class Instances:
             normalized=self.normalized,
         )
 
-    def flipud(self, h):
+    def flipud(self, h: int) -> None:
         """
         Flip coordinates vertically.
 
@@ -364,7 +371,7 @@ class Instances:
         if self.keypoints is not None:
             self.keypoints[..., 1] = h - self.keypoints[..., 1]
 
-    def fliplr(self, w):
+    def fliplr(self, w: int) -> None:
         """
         Flip coordinates horizontally.
 
@@ -382,7 +389,7 @@ class Instances:
         if self.keypoints is not None:
             self.keypoints[..., 0] = w - self.keypoints[..., 0]
 
-    def clip(self, w, h):
+    def clip(self, w: int, h: int) -> None:
         """
         Clip coordinates to stay within image boundaries.
 
@@ -406,8 +413,10 @@ class Instances:
                 | (self.keypoints[..., 1] < 0)
                 | (self.keypoints[..., 1] > h)
             ] = 0.0
+            self.keypoints[..., 0] = self.keypoints[..., 0].clip(0, w)
+            self.keypoints[..., 1] = self.keypoints[..., 1].clip(0, h)
 
-    def remove_zero_area_boxes(self):
+    def remove_zero_area_boxes(self) -> np.ndarray:
         """
         Remove zero-area boxes, i.e. after clipping some boxes may have zero width or height.
 
@@ -423,7 +432,7 @@ class Instances:
                 self.keypoints = self.keypoints[good]
         return good
 
-    def update(self, bboxes, segments=None, keypoints=None):
+    def update(self, bboxes: np.ndarray, segments: np.ndarray = None, keypoints: np.ndarray = None):
         """
         Update instance variables.
 
@@ -438,7 +447,7 @@ class Instances:
         if keypoints is not None:
             self.keypoints = keypoints
 
-    def __len__(self):
+    def __len__(self) -> int:
         """Return the number of instances."""
         return len(self.bboxes)
 
@@ -490,6 +499,6 @@ class Instances:
         return cls(cat_boxes, cat_segments, cat_keypoints, bbox_format, normalized)
 
     @property
-    def bboxes(self):
+    def bboxes(self) -> np.ndarray:
         """Return bounding boxes."""
         return self._bboxes.bboxes
